#
# spec file for package dolly
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dolly
Summary:        Tool for cloning data of one machine to other machines
License:        GPL-2.0-only
Group:          Productivity/Networking/Other
Version:        0.64.2
Release:        1.6
URL:            https://github.com/openSUSE/dolly
Source0:        dolly-%{version}.tar.xz

#SLE15* does not contain pandoc packages
%if 0%{?is_opensuse}
%ifnarch i586
BuildRequires:  firewalld
BuildRequires:  pandoc
Requires:       gzip
%endif
%endif

%description
Dolly is used to clone data of one machine to (possibly many)
other machines. It can distribute image files (even gnu-zipped),
partitions or whole hard disk drives to other partitions or
hard disk drives. As it forms a "virtual TCP ring" to distribute
data, it works best with fast switched networks.

As dolly can clone whole partitions block-wise, it works for
most filesystems, including the types for Linux, Windows, Oberon,
Solaris.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%if 0%{?is_opensuse}
%ifnarch i586
make %{?_smp_mflags}
%else
make %{?_smp_mflags} dolly
%endif
%else
make %{?_smp_mflags} dolly
%endif

%install
%make_install
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcdolly

%pre
%service_add_pre dolly.service dolly.socket

%post
%service_add_post dolly.service dolly.socket

%preun
%service_del_preun dolly.service dolly.socket

%postun
%service_del_postun dolly.service dolly.socket

%files
%doc README.md send_multiple_files.pl
%license LICENSE
%defattr(-,root,root,-)
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%attr(755,root,root) %{_sbindir}/dolly
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_prefix}/lib/firewalld/services/dolly.xml
%if 0%{?is_opensuse}
%ifnarch i586
%{_mandir}/man1/dolly.1.gz
%endif
%endif
%{_sbindir}/rcdolly
%{_unitdir}/dolly.service
%{_unitdir}/dolly.socket

%changelog
* Wed Mar 23 2022 Antoine Ginies <aginies@suse.com>
- update to dolly version 0.64.2: bugs and typo fixes, dolly is
  less verbose by default
* Wed Mar 23 2022 Christian Goll <cgoll@suse.com>
-  updated to dolly 0.64.1 which adds dolly as a service and/or
  activation through a socket
* Wed Nov 17 2021 Antoine Ginies <aginies@suse.com>
- add dolly firewall config (JSC#SLE-22730)
* Tue Nov  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Minor grammar fix in description.
* Wed Oct 13 2021 Antoine Ginies <aginies@suse.com>
- fix hostname resolution is not done in case of usage
  of an external configuration file (bsc#1191613)
- fix -Werror=format-security
- update to version 0.63.6
* Thu Oct  7 2021 Antoine Ginies <aginies@suse.com>
- update to version 0.63.5 (improve help usage information) (JSC#SLE-22050)
- tarball is now bzip2 compressed
* Mon Jun  7 2021 Christian Goll <cgoll@suse.com>
- updated to v0.63.4 which builds with gcc-11
* Tue Feb  9 2021 Christian Goll <cgoll@suse.com>
- updated to v0.63.1 which builds on i586
- disabled pandoc for i585
* Mon Feb  8 2021 Jan Engelhardt <jengelh@inai.de>
- Remove obsolete specfile constructs. Depersonalize descriptions.
* Tue Feb  2 2021 Christian Goll <cgoll@suse.com>
- fixed the Makefile to support position independent code
* Fri Jan 29 2021 Antoine Ginies <aginies@suse.com>
- fix buildrequires for SLE (no pandoc package)
* Fri Jan 29 2021 Christian Goll <cgoll@suse.com>
- updated to version 0.63
- New features:
  * hosts can be resovled to ip addresses
  * works without dns resolution
* Fri Nov 20 2020 Christian Goll <cgoll@suse.com>
- added patch file: added-retries-for-connect.patch
* Wed Sep 11 2019 Christian Goll <cgoll@suse.com>
- updated to version 0.60
* Thu Jun  6 2019 Christian Goll <cgoll@suse.com>
- added man page and moved dolly to /usr/sbin/dolly
* Wed Apr 10 2019 Antoine Ginies <aginies@suse.com>
- 0.59 version
- fix typo in my name
* Mon Apr  8 2019 Antoine Ginies <aginies@suse.com>
- 0.58C version
